function A=randnsdd(N,d,varargin)
% FUNCTION fc_amat.random.randnsdd
% -- randnsdd(N,d)
%      Return a N-by-d-by-d amat object whose matrices are strictly diagonally
%      dominant matrices with non-diagonal elements drawn from the normal 
%      distribution having zero mean and unit standard deviation.
%
% -- randnsdd(...,key,value)
%      Optional key/value pairs  arguments are available with keys:
%        - 'complex', if value is true the amat object is complex 
%                     (default false i.e real amat object)
%        - 'class', value can be 'single' or 'double' (default).
%        - 'mean', to set mean value (0 by default).
%        - 'sigma', to set  standard deviation value (1 by default).
%
%      See also: fc_amat.random.randn,
%                class amat
%
  p = inputParser; 
  p.addParamValue('complex',false,@islogical); 
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'})); 
  p.addParamValue('mean',0,@isscalar); 
  p.addParamValue('sigma',1,@isscalar); 
  p.parse(varargin{:});
  R=p.Results;
  if R.complex
    A=complex(R.mean+R.sigma*fc_amat.random.randn(N,d,d,R.class),R.mean+R.sigma*fc_amat.random.randn(N,d,d,R.class));
    s=exp(2*pi*complex(0,1)*rand(N,d,R.class));
  else
    A=R.mean+R.sigma*fc_amat.random.randn(N,d,d,R.class);
    s=-3+2*randi(2,N,d,R.class); % sign
  end
  tmp=(1+1e-6)*s.*squeeze(sum(abs(A),2)); % N-by-d
  for i=1:d
    A(i,i)=tmp(:,i);
  end
end
